bug-gnu-utils
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: Patch #1 to Gawk 3.1 now available


From: Guillaume Cottenceau
Subject: Re: Patch #1 to Gawk 3.1 now available
Date: 09 May 2002 21:32:35 +0200
User-agent: Gnus/5.09 (Gnus v5.9.0) Emacs/21.2

Aharon Robbins <address@hidden> writes:

> Patch #1 to GNU Awk (gawk) 3.1 is now available. Gawk is the GNU project's
> version of the AWK programming language.

Debian authored a security patch on 3.1.0 that we also include in
our distribution of binary gawk, and it seems it's not in 3.1.1
yet.

Do you judge the patch not valid or something?

In case you don't know the patch, I include it here:

--- gawk-3.1.0.orig/awklib/eg/prog/igawk.sh
+++ gawk-3.1.0/awklib/eg/prog/igawk.sh
@@ -4,13 +4,16 @@
 # Arnold Robbins, address@hidden, Public Domain
 # July 1993
 
+igs=`mktemp /tmp/ig.s.XXXXXX` || exit 1
+ige=`mktemp /tmp/ig.e.XXXXXX` || exit 1
+
 if [ "$1" = debug ]
 then
     set -x
     shift
 else
     # cleanup on exit, hangup, interrupt, quit, termination
-    trap 'rm -f /tmp/ig.[se].$$' 0 1 2 3 15
+    trap 'rm -f $igs $ige' 0 1 2 3 15
 fi
 
 while [ $# -ne 0 ] # loop over arguments
@@ -27,26 +30,26 @@
 
     -[vF]*) opts="$opts '$1'" ;;
 
-    -f)     echo @include "$2" >> /tmp/ig.s.$$
+    -f)     echo @include "$2" >> $igs
             shift;;
 
     -f*)    f=`echo "$1" | sed 's/-f//'`
-            echo @include "$f" >> /tmp/ig.s.$$ ;;
+            echo @include "$f" >> $igs ;;
 
     -?file=*)    # -Wfile or --file
             f=`echo "$1" | sed 's/-.file=//'`
-            echo @include "$f" >> /tmp/ig.s.$$ ;;
+            echo @include "$f" >> $igs ;;
 
     -?file)      # get arg, $2
-            echo @include "$2" >> /tmp/ig.s.$$
+            echo @include "$2" >> $igs
             shift;;
 
     -?source=*)  # -Wsource or --source
             t=`echo "$1" | sed 's/-.source=//'`
-            echo "$t" >> /tmp/ig.s.$$ ;;
+            echo "$t" >> $igs ;;
 
     -?source)    # get arg, $2
-            echo "$2" >> /tmp/ig.s.$$
+            echo "$2" >> $igs
             shift;;
 
     -?version)
@@ -61,19 +64,19 @@
     shift
 done
 
-if [ ! -s /tmp/ig.s.$$ ]
+if [ ! -s $igs ]
 then
     if [ -z "$1" ]
     then
          echo igawk: no program! 1>&2
          exit 1
     else
-        echo "$1" > /tmp/ig.s.$$
+        echo "$1" > $igs
         shift
     fi
 fi
 
 # at this point, /tmp/ig.s.$$ has the program
 gawk -- '
 # process @include directives
 
@@ -124,7 +127,7 @@
         }
         close(input[stackptr])
     }
-}' /tmp/ig.s.$$ > /tmp/ig.e.$$
-eval gawk -f /tmp/ig.e.$$ $opts -- "$@"
+}' $igs > $ige
+eval gawk -f $ige $opts -- "$@"
 
 exit $?
@@ -61,19 +64,19 @@
 fi
 
-# at this point, /tmp/ig.s.$$ has the program
+# at this point, $igs has the program
 gawk -- '
 # process @include directives


-- 
Guillaume Cottenceau - http://people.mandrakesoft.com/~gc/



reply via email to

[Prev in Thread] Current Thread [Next in Thread]